@@ -2,7 +2,7 @@
 #
 #       config.py
 #
-#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ def config_file_load(inst):
         else: inst.toolbar_icon_size = 1
         
         section = "tree"
-        inst.expand_tree = config.getboolean(section, "expand_tree") if config.has_option(section, "expand_tree") else False
+        inst.rest_exp_coll = config.getint(section, "rest_exp_coll") if config.has_option(section, "rest_exp_coll") else 0
         inst.expanded_collapsed_string = config.get(section, "expanded_collapsed_string") if config.has_option(section, "expanded_collapsed_string") else ""
         inst.nodes_icons = config.get(section, "nodes_icons") if config.has_option(section, "nodes_icons") else "c"
         inst.tree_right_side = config.getboolean(section, "tree_right_side") if config.has_option(section, "tree_right_side") else False
@@ -168,7 +168,7 @@ def config_file_load(inst):
         inst.systray = False
         inst.autosave = [False, 5]
         inst.win_is_maximized = False
-        inst.expand_tree = False
+        inst.rest_exp_coll = 0
         inst.expanded_collapsed_string = ""
         inst.pick_dir = ""
         inst.link_type = "webs"
@@ -209,7 +209,7 @@ def config_file_apply(inst):
     else: user_active_restore = False
     # treeview
     inst.hpaned.set_property('position', inst.hpaned_pos)
-    inst.header_node_name_label.set_property(cons.STR_VISIBLE, inst.show_node_name_label)
+    inst.header_node_name_label.set_visible(inst.show_node_name_label)
     inst.set_treeview_font()
     inst.glade.fontbutton_tree.set_font_name(inst.tree_font)
     # sourceview
@@ -257,7 +257,9 @@ def config_file_apply(inst):
     inst.glade.spinbutton_autosave.set_value(inst.autosave[1])
     inst.glade.spinbutton_autosave.set_sensitive(inst.autosave[0])
     inst.glade.checkbutton_autosave.set_active(inst.autosave[0])
-    inst.glade.checkbutton_expand_tree.set_active(inst.expand_tree)
+    inst.glade.radiobutton_nodes_startup_restore.set_active(inst.rest_exp_coll == 0)
+    inst.glade.radiobutton_nodes_startup_expand.set_active(inst.rest_exp_coll == 1)
+    inst.glade.radiobutton_nodes_startup_collapse.set_active(inst.rest_exp_coll == 2)
     inst.glade.checkbutton_newer_version.set_active(inst.check_version)
     inst.glade.checkbutton_mod_time_sentinel.set_active(inst.enable_mod_time_sentinel)
     inst.glade.checkbutton_backup_before_saving.set_active(inst.backup_copy)
@@ -285,8 +287,8 @@ def config_file_apply(inst):
     inst.glade.table_column_rename_radiobutton.set_active(inst.table_column_mode == "rename")
     inst.glade.table_column_delete_radiobutton.set_active(inst.table_column_mode == "delete")
     inst.glade.table_column_add_radiobutton.set_active(inst.table_column_mode == "add")
-    inst.glade.table_column_left_radiobutton.set_active(inst.table_column_mode == "left")
-    inst.glade.table_column_right_radiobutton.set_active(inst.table_column_mode == "right")
+    inst.glade.table_column_left_radiobutton.set_active(inst.table_column_mode == cons.TAG_PROP_LEFT)
+    inst.glade.table_column_right_radiobutton.set_active(inst.table_column_mode == cons.TAG_PROP_RIGHT)
     inst.glade.radiobutton_node_icon_cherry.set_active(inst.nodes_icons == "c")
     inst.glade.radiobutton_node_icon_bullet.set_active(inst.nodes_icons == "b")
     inst.glade.radiobutton_node_icon_none.set_active(inst.nodes_icons == "n")
@@ -297,7 +299,7 @@ def config_file_apply(inst):
     inst.glade.spinbutton_limit_undoable_steps.set_value(inst.limit_undoable_steps)
     inst.glade.spinbutton_tree_nodes_names_width.set_value(inst.cherry_wrap_width)
     inst.renderer_text.set_property('wrap-width', inst.cherry_wrap_width)
-    inst.ui.get_widget("/ToolBar").set_property(cons.STR_VISIBLE, inst.toolbar_visible)
+    inst.ui.get_widget("/ToolBar").set_visible(inst.toolbar_visible)
     inst.ui.get_widget("/ToolBar").set_style(gtk.TOOLBAR_ICONS)
     inst.ui.get_widget("/ToolBar").set_property("icon-size", ICONS_SIZE[inst.toolbar_icon_size])
     if inst.autosave[0]: inst.autosave_timer_start()
@@ -311,7 +313,7 @@ def config_file_save(inst):
     config.add_section(section)
     config.set(section, "file_dir", inst.file_dir)
     config.set(section, "file_name", inst.file_name)
-    config.set(section, "toolbar_visible", inst.ui.get_widget("/ToolBar").get_property(cons.STR_VISIBLE))
+    config.set(section, "toolbar_visible", inst.ui.get_widget("/ToolBar").get_visible())
     config.set(section, "win_is_maximized", inst.win_is_maximized)
     win_position = inst.window.get_position()
     config.set(section, "win_position_x", win_position[0])
@@ -326,7 +328,7 @@ def config_file_save(inst):
         for element in inst.treestore.get_path(inst.curr_tree_iter):
             path_list_of_str.append( str(element) )
         config.set(section, "node_path", " ".join(path_list_of_str))
-        config.set(section, "cursor_position", inst.curr_buffer.get_property('cursor-position'))
+        config.set(section, "cursor_position", inst.curr_buffer.get_property(cons.STR_CURSOR_POSITION))
     if inst.recent_docs:
         temp_recent_docs = []
         for element in inst.recent_docs:
@@ -336,13 +338,13 @@ def config_file_save(inst):
     config.set(section, "recent_docs", str_recent_docs)
     config.set(section, "pick_dir", inst.pick_dir)
     config.set(section, "link_type", inst.link_type)
-    config.set(section, "show_node_name_label", inst.header_node_name_label.get_property(cons.STR_VISIBLE))
+    config.set(section, "show_node_name_label", inst.header_node_name_label.get_visible())
     config.set(section, "toolbar_icon_size", inst.toolbar_icon_size)
     
     section = "tree"
     config.add_section(section)
-    config.set(section, "expand_tree", inst.expand_tree)
-    if not inst.expand_tree:
+    config.set(section, "rest_exp_coll", inst.rest_exp_coll)
+    if inst.rest_exp_coll == 0:
         get_tree_expanded_collapsed_string(inst)
         config.set(section, "expanded_collapsed_string", inst.expanded_collapsed_string)
     config.set(section, "nodes_icons", inst.nodes_icons)
