@@ -2,7 +2,7 @@
 #
 #       cons.py
 #
-#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -22,30 +22,35 @@
 import os, sys
 
 
-VERSION = "0.28.5"
+VERSION = "0.29"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform[0:3] == "win":
-    EXE_DIR = os.getcwd()
-    CONFIG_PATH = os.path.join(EXE_DIR, 'config.cfg')
-    LANG_PATH = os.path.join(EXE_DIR, 'lang')
-    IMG_PATH = os.path.join(EXE_DIR, 'glade/img_tmp.png')
-    TMP_FOLDER = os.path.join(EXE_DIR, 'glade/ct_tmp/')
+    IS_WIN_OS = True
+    CONFIG_DIR = os.path.join(os.environ['APPDATA'], APP_NAME)
+    if SHARE_PATH:
+        EXE_DIR = SHARE_PATH
+        os.chdir(EXE_DIR)
+    else: EXE_DIR = os.getcwd()
+    TMP_FOLDER = os.path.join(os.environ['TEMP'], 'ct_tmp/')
     GLADE_PATH = os.path.join(EXE_DIR, 'glade/')
     LOCALE_PATH = os.path.join(EXE_DIR, 'locale/')
 else:
-    CONFIG_PATH = os.path.join(os.path.expanduser('~'), '.config/cherrytree/config.cfg')
-    LANG_PATH = os.path.join(os.path.expanduser('~'), '.config/cherrytree/lang')
-    IMG_PATH = os.path.join(os.path.expanduser('~'), '.config/cherrytree/img_tmp.png')
+    IS_WIN_OS = False
+    CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config/cherrytree')
     TMP_FOLDER = '/tmp/ct_tmp/'
-    if os.path.isfile('modules/cons.py'):
+    if not SHARE_PATH:
         GLADE_PATH = os.path.join(os.getcwd(), "glade/")
         LOCALE_PATH = 'locale/'
     else:
         GLADE_PATH = os.path.join(SHARE_PATH, 'cherrytree/glade/')
         LOCALE_PATH = os.path.join(SHARE_PATH, 'locale')
+CONFIG_PATH = os.path.join(CONFIG_DIR, 'config.cfg')
+LANG_PATH = os.path.join(CONFIG_DIR, 'lang')
+IMG_PATH = os.path.join(CONFIG_DIR, 'img_tmp.png')
+
 AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'it', 'pl', 'ru', 'uk', 'zh_CN']
-COLOR_48_YELLOW = "#ffffffff0000"
+COLOR_48_YELLOW = "#bbbbbbbb0000"
 COLOR_48_WHITE = "#ffffffffffff"
 COLOR_48_BLACK = "#000000000000"
 COLOR_24_BLACK = "#000000"
@@ -62,8 +67,33 @@ TREE_TEXT_DARK_BG = COLOR_24_BLUEBG
 TREE_TEXT_LIGHT_FG = COLOR_24_LBLACK
 TREE_TEXT_LIGHT_BG = COLOR_24_GRAY
 BAD_CHARS = "[\x00-\x08\x0b-\x1f]"
-TAG_PROPERTIES = ["weight", "foreground", "background", "style", "underline", "strikethrough",
-                  "scale", "family", "justification", "link"]
+
+TAG_WEIGHT = "weight"
+TAG_FOREGROUND = "foreground"
+TAG_BACKGROUND = "background"
+TAG_STYLE = "style"
+TAG_UNDERLINE = "underline"
+TAG_STRIKETHROUGH = "strikethrough"
+TAG_SCALE = "scale"
+TAG_FAMILY = "family"
+TAG_JUSTIFICATION = "justification"
+TAG_LINK = "link"
+TAG_PROP_HEAVY = "heavy"
+TAG_PROP_ITALIC = "italic"
+TAG_PROP_MONOSPACE = "monospace"
+TAG_PROP_SINGLE = "single"
+TAG_PROP_TRUE = "true"
+TAG_PROP_H1 = "h1"
+TAG_PROP_H2 = "h2"
+TAG_PROP_H3 = "h3"
+TAG_PROP_SUP = "sup"
+TAG_PROP_SUB = "sub"
+TAG_PROP_LEFT = "left"
+TAG_PROP_CENTER = "center"
+TAG_PROP_RIGHT = "right"
+TAG_PROPERTIES = [TAG_WEIGHT, TAG_FOREGROUND, TAG_BACKGROUND, TAG_STYLE, TAG_UNDERLINE,
+                  TAG_STRIKETHROUGH, TAG_SCALE, TAG_FAMILY, TAG_JUSTIFICATION, TAG_LINK]
+
 CUSTOM_COLORS_ID = "custom-colors"
 STYLE_SCHEME_DEFAULT = "cobalt"
 ANCHOR_CHAR = GLADE_PATH + 'anchor.png'
@@ -93,6 +123,14 @@ CHAR_PARENTH_OPEN = "("
 CHAR_PARENTH_CLOSE = ")"
 CHAR_LESSER = "<"
 CHAR_GREATER = ">"
+CHAR_STAR = "*"
+CHAR_SLASH = "/"
+CHAR_USCORE = "_"
+CHAR_EQUAL = "="
+CHAR_BR_OPEN = "{"
+CHAR_BR_CLOSE = "}"
+CHAR_CARET = "^"
+CHAR_PIPE = "|"
 
 SPECIAL_CHAR_ARROW_RIGHT = "→"
 SPECIAL_CHAR_ARROW_LEFT = "←"
@@ -101,7 +139,8 @@ SPECIAL_CHAR_COPYRIGHT = "©"
 SPECIAL_CHAR_UNREGISTERED_TRADEMARK = "™"
 SPECIAL_CHAR_REGISTERED_TRADEMARK = "®"
 
-STR_VISIBLE = "visible"
+STR_CURSOR_POSITION = "cursor-position"
+STR_STOCK_CT_IMP = "import_in_cherrytree"
 
 HTML_HEADER = '<!doctype html><html><head><meta http-equiv="content-type" content="text/html; charset=utf-8"><title>%s</title><meta name="generator" content="CherryTree"></head><body>'
 HTML_FOOTER = '</body></html>'
@@ -158,6 +197,10 @@ STOCKS_N_FILES = ['node_bullet.png',
                   'format-text-subscript.png',
                   'format-text-superscript.png',
                   'format-text-monospace.png',
+                  'format-text-strikethrough.png',
+                  'format-text-underline.png',
+                  'format-text-bold.png',
+                  'format-text-italic.png',
                   'format_text_latest.png',
                   'format_text.png',
                   'object-rotate-left.png',
@@ -165,7 +208,7 @@ STOCKS_N_FILES = ['node_bullet.png',
                   'to_txt.png',
                   'to_html.png',
                   'export_from_cherrytree.png',
-                  'import_in_cherrytree.png',
+                  STR_STOCK_CT_IMP + '.png',
                   'cherrytree.png',
                   'quit-app.png',
                   'new-instance.png',
@@ -336,6 +379,8 @@ UI_INFO = """
             <menuitem action='ShowHideNodeNameHeader'/>
             <menuitem action='ShowAllMatchesDialog'/>
             <separator/>
+            <menuitem action='ToggleTreeText'/>
+            <separator/>
             <menuitem action='IncreaseToolbarIconsSize'/>
             <menuitem action='DecreaseToolbarIconsSize'/>
             <separator/>
@@ -359,6 +404,7 @@ UI_INFO = """
             <menuitem action='FromTomboy'/>
             <menuitem action='FromTreepad'/>
             <menuitem action='FromTuxCards'/>
+            <menuitem action='FromZim'/>
         </menu>
 
         <menu action='ExportMenu'>
@@ -470,7 +516,7 @@ def get_entries(inst):
     ( "FormattingMenu", None, _("For_matting") ),
     ( "TreeMenu", None, _("_Tree") ),
     ( "TreeMoveMenu", "gtk-jump-to", _("Node _Move") ),
-    ( "TreeImportMenu", "import_in_cherrytree", _("Nodes _Import") ),
+    ( "TreeImportMenu", STR_STOCK_CT_IMP, _("Nodes _Import") ),
     ( "TreeExportMenu", "export_from_cherrytree", _("Nodes E_xport") ),
     ( "ChangeCaseMenu", "case_toggle", _("C_hange Case") ),
     ( "SearchMenu", None, _("_Search") ),
@@ -531,10 +577,10 @@ def get_entries(inst):
     ( "RemoveFormatting", "gtk-clear", _("_Remove Formatting"), None, _("Remove the Formatting from the Selected Text"), inst.remove_text_formatting),
     ( "ColorForeground", "color_foreground", _("Text _Color Foreground"), None, _("Change the Color of the Selected Text Foreground"), inst.apply_tag_foreground),
     ( "ColorBackground", "color_background", _("Text C_olor Background"), None, _("Change the Color of the Selected Text Background"), inst.apply_tag_background),
-    ( "Bold", "gtk-bold", _("Toggle _Bold Property"), "<control>B", _("Toggle Bold Property of the Selected Text"), inst.apply_tag_bold),
-    ( "Italic", "gtk-italic", _("Toggle _Italic Property"), "<control>I", _("Toggle Italic Property of the Selected Text"), inst.apply_tag_italic),
-    ( "Underline", "gtk-underline", _("Toggle _Underline Property"), "<control>U", _("Toggle Underline Property of the Selected Text"), inst.apply_tag_underline),
-    ( "Strikethrough", "gtk-strikethrough", _("Toggle Stri_kethrough Property"), "<control>E", _("Toggle Strikethrough Property of the Selected Text"), inst.apply_tag_strikethrough),
+    ( "Bold", "format-text-bold", _("Toggle _Bold Property"), "<control>B", _("Toggle Bold Property of the Selected Text"), inst.apply_tag_bold),
+    ( "Italic", "format-text-italic", _("Toggle _Italic Property"), "<control>I", _("Toggle Italic Property of the Selected Text"), inst.apply_tag_italic),
+    ( "Underline", "format-text-underline", _("Toggle _Underline Property"), "<control>U", _("Toggle Underline Property of the Selected Text"), inst.apply_tag_underline),
+    ( "Strikethrough", "format-text-strikethrough", _("Toggle Stri_kethrough Property"), "<control>E", _("Toggle Strikethrough Property of the Selected Text"), inst.apply_tag_strikethrough),
     ( "H1", "format-text-large", _("Toggle h_1 Property"), "<control>1", _("Toggle h1 Property of the Selected Text"), inst.apply_tag_h1),
     ( "H2", "format-text-large2", _("Toggle h_2 Property"), "<control>2", _("Toggle h2 Property of the Selected Text"), inst.apply_tag_h2),
     ( "H3", "format-text-large3", _("Toggle h_3 Property"), "<control>3", _("Toggle h3 Property of the Selected Text"), inst.apply_tag_h3),
@@ -556,23 +602,25 @@ def get_entries(inst):
     ( "ReplaceAgain", "find_replace", _("Replace _Again"), "F6", _("Iterate the Last Replace Operation"), inst.replace_again),
     ( "ShowHideNodeNameHeader", "node_name_header", _("Show/Hide Node Name _Header"), None, _("Toggle Show/Hide Node Name Header"), inst.toggle_show_hide_node_name_header),
     ( "ShowHideTree", "cherries", _("Show/Hide _Tree"), "F9", _("Toggle Show/Hide Tree"), inst.toggle_show_hide_tree),
-    ( "ShowHideMainWin", "cherrytree", _("Show/Hide _CherryTree"), None, _("Toggle Show/Hide CherryTree"), inst.toggle_show_hide_main_window),
+    ( "ShowHideMainWin", APP_NAME, _("Show/Hide _CherryTree"), None, _("Toggle Show/Hide CherryTree"), inst.toggle_show_hide_main_window),
     ( "ShowHideToolbar", "toolbar", _("Show/Hide Tool_bar"), None, _("Toggle Show/Hide Toolbar"), inst.toggle_show_hide_toolbar),
     ( "ShowAllMatchesDialog", "find", _("Show _All Matches Dialog"), "<control><shift>A", _("Show Search All Matches Dialog"), inst.find_allmatchesdialog_restore),
     ( "IncreaseToolbarIconsSize", "gtk-add", _("_Increase Toolbar Icons Size"), None, _("Increase the Size of the Toolbar Icons"), inst.toolbar_icons_size_increase),
     ( "DecreaseToolbarIconsSize", "gtk-remove", _("_Decrease Toolbar Icons Size"), None, _("Decrease the Size of the Toolbar Icons"), inst.toolbar_icons_size_decrease),
+    ( "ToggleTreeText", "gtk-jump-to", _("Toggle Focus Tree/Text"), "<control>J", _("Toggle Focus Between Tree and Text"), inst.toggle_tree_text),
     ( "Fullscreen", "gtk-fullscreen", _("_Full Screen On/Off"), "F11", _("Toggle Full Screen On/Off"), inst.fullscreen_toggle),
-    ( "FromBasket", "import_in_cherrytree", _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
-    ( "FromCherryTree", "import_in_cherrytree", _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
-    ( "FromNoteCase", "import_in_cherrytree", _("From _NoteCase File"), None, _("Add Nodes of a NoteCase File to the Current Tree"), inst.nodes_add_from_notecase_file),
-    ( "FromKeepNote", "import_in_cherrytree", _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
-    ( "FromKnowit", "import_in_cherrytree", _("From K_nowit File"), None, _("Add Nodes of a Knowit File to the Current Tree"), inst.nodes_add_from_knowit_file),
-    ( "FromTomboy", "import_in_cherrytree", _("From T_omboy Folder"), None, _("Add Nodes of a Tomboy Folder to the Current Tree"), inst.nodes_add_from_tomboy_folder),
-    ( "FromGnote", "import_in_cherrytree", _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
-    ( "FromTuxCards", "import_in_cherrytree", _("From _TuxCards File"), None, _("Add Nodes of a TuxCards File to the Current Tree"), inst.nodes_add_from_tuxcards_file),
-    ( "FromTreepad", "import_in_cherrytree", _("From T_reepad Lite File"), None, _("Add Nodes of a Treepad Lite File to the Current Tree"), inst.nodes_add_from_treepad_file),
-    ( "FromMempad", "import_in_cherrytree", _("From _Mempad File"), None, _("Add Nodes of a Mempad File to the Current Tree"), inst.nodes_add_from_mempad_file),
-    ( "FromLeo", "import_in_cherrytree", _("From _Leo File"), None, _("Add Nodes of a Leo File to the Current Tree"), inst.nodes_add_from_leo_file),
+    ( "FromBasket", STR_STOCK_CT_IMP, _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
+    ( "FromCherryTree", STR_STOCK_CT_IMP, _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
+    ( "FromNoteCase", STR_STOCK_CT_IMP, _("From _NoteCase File"), None, _("Add Nodes of a NoteCase File to the Current Tree"), inst.nodes_add_from_notecase_file),
+    ( "FromKeepNote", STR_STOCK_CT_IMP, _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
+    ( "FromKnowit", STR_STOCK_CT_IMP, _("From K_nowit File"), None, _("Add Nodes of a Knowit File to the Current Tree"), inst.nodes_add_from_knowit_file),
+    ( "FromZim", STR_STOCK_CT_IMP, _("From _Zim Folder"), None, _("Add Nodes of a Zim Folder to the Current Tree"), inst.nodes_add_from_zim_folder),
+    ( "FromTomboy", STR_STOCK_CT_IMP, _("From T_omboy Folder"), None, _("Add Nodes of a Tomboy Folder to the Current Tree"), inst.nodes_add_from_tomboy_folder),
+    ( "FromGnote", STR_STOCK_CT_IMP, _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
+    ( "FromTuxCards", STR_STOCK_CT_IMP, _("From _TuxCards File"), None, _("Add Nodes of a TuxCards File to the Current Tree"), inst.nodes_add_from_tuxcards_file),
+    ( "FromTreepad", STR_STOCK_CT_IMP, _("From T_reepad Lite File"), None, _("Add Nodes of a Treepad Lite File to the Current Tree"), inst.nodes_add_from_treepad_file),
+    ( "FromMempad", STR_STOCK_CT_IMP, _("From _Mempad File"), None, _("Add Nodes of a Mempad File to the Current Tree"), inst.nodes_add_from_mempad_file),
+    ( "FromLeo", STR_STOCK_CT_IMP, _("From _Leo File"), None, _("Add Nodes of a Leo File to the Current Tree"), inst.nodes_add_from_leo_file),
     ( "Help", "help-contents", _("Online _Manual"), None, _("Application's Online Manual"), inst.on_help_menu_item_activated),
     ( "CheckNewer", "gtk-network", _("_Check Newer Version"), None, _("Check for a Newer Version"), inst.check_for_newer_version),
     ( "About", "gtk-about", _("_About"), None, _("About CherryTree"), inst.dialog_about),
@@ -626,18 +674,19 @@ def get_popup_menu_tree(inst):
     ("find", _("Find a _Node"), "<control>T", _("Find a Node from its Name"), inst.find_a_node),
     ("find_replace", _("Replace in Nodes _Names"), "<control><shift>T", _("Replace in Nodes Names"), inst.replace_in_nodes_names),
     ("separator", None, None, None, None),
-    ("submenu-start", _("Nodes _Import"), "import_in_cherrytree", None, None),
-    ("import_in_cherrytree", _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
-    ("import_in_cherrytree", _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
-    ("import_in_cherrytree", _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
-    ("import_in_cherrytree", _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
-    ("import_in_cherrytree", _("From K_nowit File"), None, _("Add Nodes of a Knowit File to the Current Tree"), inst.nodes_add_from_knowit_file),
-    ("import_in_cherrytree", _("From _Leo File"), None, _("Add Nodes of a Leo File to the Current Tree"), inst.nodes_add_from_leo_file),
-    ("import_in_cherrytree", _("From _Mempad File"), None, _("Add Nodes of a Mempad File to the Current Tree"), inst.nodes_add_from_mempad_file),
-    ("import_in_cherrytree", _("From _NoteCase File"), None, _("Add Nodes of a NoteCase File to the Current Tree"), inst.nodes_add_from_notecase_file),
-    ("import_in_cherrytree", _("From T_omboy Folder"), None, _("Add Nodes of a Tomboy Folder to the Current Tree"), inst.nodes_add_from_tomboy_folder),
-    ("import_in_cherrytree", _("From T_reepad Lite File"), None, _("Add Nodes of a Treepad Lite File to the Current Tree"), inst.nodes_add_from_treepad_file),
-    ("import_in_cherrytree", _("From _TuxCards File"), None, _("Add Nodes of a TuxCards File to the Current Tree"), inst.nodes_add_from_tuxcards_file),
+    ("submenu-start", _("Nodes _Import"), STR_STOCK_CT_IMP, None, None),
+    (STR_STOCK_CT_IMP, _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
+    (STR_STOCK_CT_IMP, _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
+    (STR_STOCK_CT_IMP, _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
+    (STR_STOCK_CT_IMP, _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
+    (STR_STOCK_CT_IMP, _("From K_nowit File"), None, _("Add Nodes of a Knowit File to the Current Tree"), inst.nodes_add_from_knowit_file),
+    (STR_STOCK_CT_IMP, _("From _Leo File"), None, _("Add Nodes of a Leo File to the Current Tree"), inst.nodes_add_from_leo_file),
+    (STR_STOCK_CT_IMP, _("From _Mempad File"), None, _("Add Nodes of a Mempad File to the Current Tree"), inst.nodes_add_from_mempad_file),
+    (STR_STOCK_CT_IMP, _("From _NoteCase File"), None, _("Add Nodes of a NoteCase File to the Current Tree"), inst.nodes_add_from_notecase_file),
+    (STR_STOCK_CT_IMP, _("From T_omboy Folder"), None, _("Add Nodes of a Tomboy Folder to the Current Tree"), inst.nodes_add_from_tomboy_folder),
+    (STR_STOCK_CT_IMP, _("From T_reepad Lite File"), None, _("Add Nodes of a Treepad Lite File to the Current Tree"), inst.nodes_add_from_treepad_file),
+    (STR_STOCK_CT_IMP, _("From _TuxCards File"), None, _("Add Nodes of a TuxCards File to the Current Tree"), inst.nodes_add_from_tuxcards_file),
+    (STR_STOCK_CT_IMP, _("From _Zim Folder"), None, _("Add Nodes of a Zim Folder to the Current Tree"), inst.nodes_add_from_zim_folder),
     ("submenu-end", None, None, None, None),
     ("submenu-start", _("Nodes E_xport"), "export_from_cherrytree", None, None),
     ("gtk-print", _("_Print / Export To PDF"), "<control>P", _("Print / Export To PDF"), inst.export_print),
@@ -670,10 +719,10 @@ def get_popup_menu_entries_text(inst):
     ("separator", None, None, None, None),
     ("color_foreground", _("Text _Color Foreground"), None, _("Change the Color of the Selected Text Foreground"), inst.apply_tag_foreground),
     ("color_background", _("Text C_olor Background"), None, _("Change the Color of the Selected Text Background"), inst.apply_tag_background),
-    ("gtk-bold", _("Toggle _Bold Property"), "<control>B", _("Toggle Bold Property of the Selected Text"), inst.apply_tag_bold),
-    ("gtk-italic", _("Toggle _Italic Property"), "<control>I", _("Toggle Italic Property of the Selected Text"), inst.apply_tag_italic),
-    ("gtk-underline", _("Toggle _Underline Property"), "<control>U", _("Toggle Underline Property of the Selected Text"), inst.apply_tag_underline),
-    ("gtk-strikethrough", _("Toggle Stri_kethrough Property"), "<control>E", _("Toggle Strikethrough Property of the Selected Text"), inst.apply_tag_strikethrough),
+    ("format-text-bold", _("Toggle _Bold Property"), "<control>B", _("Toggle Bold Property of the Selected Text"), inst.apply_tag_bold),
+    ("format-text-italic", _("Toggle _Italic Property"), "<control>I", _("Toggle Italic Property of the Selected Text"), inst.apply_tag_italic),
+    ("format-text-underline", _("Toggle _Underline Property"), "<control>U", _("Toggle Underline Property of the Selected Text"), inst.apply_tag_underline),
+    ("format-text-strikethrough", _("Toggle Stri_kethrough Property"), "<control>E", _("Toggle Strikethrough Property of the Selected Text"), inst.apply_tag_strikethrough),
     ("format-text-large", _("Toggle h_1 Property"), "<control>1", _("Toggle h1 Property of the Selected Text"), inst.apply_tag_h1),
     ("format-text-large2", _("Toggle h_2 Property"), "<control>2", _("Toggle h2 Property of the Selected Text"), inst.apply_tag_h2),
     ("format-text-large3", _("Toggle h_3 Property"), "<control>3", _("Toggle h3 Property of the Selected Text"), inst.apply_tag_h3),
