@@ -201,10 +201,28 @@ class CTDBHandler:
             node_just_inserted = not self.nodes_to_write_dict[node_id]['upd']
             del self.nodes_to_write_dict[node_id]
             if node_just_inserted:
+                # check if there are also children just added
+                tree_iter = self.dad.get_tree_iter_from_node_id(node_id)
+                tree_iter_children = self.dad.treestore.iter_children(tree_iter)
+                while tree_iter_children:
+                    self.pending_rm_just_added_node_children(tree_iter_children)
+                    tree_iter_children = self.dad.treestore.iter_next(tree_iter_children)
                 # no need to rm the node, we just do not add it
                 return
         self.nodes_to_rm_set.add(node_id)
     
+    def pending_rm_just_added_node_children(self, tree_iter):
+        """Handle situation of nodes children just added and immediately removed"""
+        node_id = self.dad.treestore[tree_iter][3]
+        node_just_inserted = node_id in self.nodes_to_write_dict and not self.nodes_to_write_dict[node_id]['upd']
+        if node_just_inserted:
+            print "pending_rm_just_added_node_children", node_id
+            del self.nodes_to_write_dict[node_id]
+        tree_iter_children = self.dad.treestore.iter_children(tree_iter)
+        while tree_iter_children:
+            self.pending_rm_just_added_node_children(tree_iter_children)
+            tree_iter_children = self.dad.treestore.iter_next(tree_iter_children)
+    
     def remove_db_node_n_children(self, db, node_id):
         """Remove a Node and his children from DB"""
         db.execute('DELETE FROM codebox WHERE node_id=?', (node_id,))
@@ -419,7 +437,7 @@ class CTDBHandler:
         syntax_highlighting = self.dad.treestore[tree_iter][4]
         if original_id: node_id = original_id
         else: node_id = self.dad.treestore[tree_iter][3]
-        print "read node content, node_id", node_id
+        #print "read node content, node_id", node_id
         self.dad.treestore[tree_iter][2] = self.dad.buffer_create(syntax_highlighting)
         curr_buffer = self.dad.treestore[tree_iter][2]
         node_row = db.execute('SELECT txt, has_codebox, has_table, has_image FROM node WHERE node_id=?', (node_id,)).fetchone()
@@ -495,7 +513,6 @@ class CTDBHandler:
         """Read a node and his children from DB"""
         if not discard_ids:
             unique_id = node_row['node_id']
-            self.dad.node_id_add(unique_id)
         else: unique_id = self.dad.node_id_get()
         node_tags = node_row['tags']
         readonly = node_row['is_ro']
