@@ -2,7 +2,7 @@
 #
 #       exports.py
 #
-#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -244,7 +244,7 @@ class Export2Pango:
             curr_tags = curr_iter.get_tags()
             if len(curr_tags) > 0:
                 curr_tag_str = curr_tags[0].get_property("foreground-gdk").to_string()
-                font_weight = curr_tags[0].get_property("weight")
+                font_weight = curr_tags[0].get_property(cons.TAG_WEIGHT)
                 if curr_tag_str == cons.COLOR_48_BLACK:
                     if former_tag_str != curr_tag_str:
                         former_tag_str = curr_tag_str
@@ -331,10 +331,10 @@ class Export2Pango:
         subscript_active = False
         monospace_active = False
         for tag_property in cons.TAG_PROPERTIES:
-            if tag_property not in ["justification", "link"] and self.curr_attributes[tag_property] != '':
+            if tag_property not in [cons.TAG_JUSTIFICATION, cons.TAG_LINK] and self.curr_attributes[tag_property] != '':
                 property_value = self.curr_attributes[tag_property]
                 # tag names fix
-                if tag_property == "scale":
+                if tag_property == cons.TAG_SCALE:
                     if property_value == "sup":
                         superscript_active = True
                         continue
@@ -344,10 +344,10 @@ class Export2Pango:
                     else: tag_property = "size"
                     # tag properties fix
                     if property_value == "small": property_value = 'x-small'
-                    elif property_value == "h1": property_value = 'xx-large'
-                    elif property_value == "h2": property_value = 'x-large'
-                    elif property_value == "h3": property_value = 'large'
-                elif tag_property == "family":
+                    elif property_value == cons.TAG_PROP_H1: property_value = 'xx-large'
+                    elif property_value == cons.TAG_PROP_H2: property_value = 'x-large'
+                    elif property_value == cons.TAG_PROP_H3: property_value = 'large'
+                elif tag_property == cons.TAG_FAMILY:
                     monospace_active = True
                     continue
                 pango_attrs += ' %s="%s"' % (tag_property, property_value)
@@ -450,8 +450,8 @@ class Export2Html:
         html_text = cons.HTML_HEADER % self.dad.treestore[tree_iter][1]
         if self.tree_links_text:
             html_text += r'<table width="100%"><tr>'
-            td_tree = r'<td valign="top" align="left" width=20%>'
-            td_page = r'<td valign="top" align="left" width=80%>'
+            td_tree = r'<td valign="top" align=cons.TAG_PROP_LEFT width=20%>'
+            td_page = r'<td valign="top" align=cons.TAG_PROP_LEFT width=80%>'
             html_text += td_tree + self.tree_links_text + td_page
         pango_font = pango.FontDescription(self.dad.text_font if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID else self.dad.code_font)
         html_text += '<span style="font-family: %s; font-size:%spt">' % (pango_font.get_family(), pango_font.get_size()/pango.SCALE)
@@ -497,14 +497,14 @@ class Export2Html:
     def table_export_to_html(self, table_dict):
         """Returns the HTML given the table dict"""
         html_text = cons.HTML_HEADER % ""
-        html_text += self.get_table_html([0, table_dict, "left"])
+        html_text += self.get_table_html([0, table_dict, cons.TAG_PROP_LEFT])
         html_text += cons.HTML_FOOTER
         return html_text
 
     def codebox_export_to_html(self, codebox_dict):
         """Returns the HTML given the table dict"""
         html_text = cons.HTML_HEADER % ""
-        html_text += self.get_codebox_html([0, codebox_dict, "left"])
+        html_text += self.get_codebox_html([0, codebox_dict, cons.TAG_PROP_LEFT])
         html_text += cons.HTML_FOOTER
         return html_text
 
@@ -555,8 +555,8 @@ class Export2Html:
 
     def get_object_alignment_string(self, alignment):
         """Returns the style attribute(s) according to the alignment"""
-        if alignment == "center": return "margin-left:auto;margin-right:auto"
-        elif alignment == "right": return "margin-left:auto"
+        if alignment == cons.TAG_PROP_CENTER: return "margin-left:auto;margin-right:auto"
+        elif alignment == cons.TAG_PROP_RIGHT: return "margin-left:auto"
         else: return "display:inline-table"
 
     def get_html_filename(self, tree_iter):
@@ -581,7 +581,7 @@ class Export2Html:
             curr_tags = curr_iter.get_tags()
             if len(curr_tags) > 0:
                 curr_tag_str = curr_tags[0].get_property("foreground-gdk").to_string()
-                font_weight = curr_tags[0].get_property("weight")
+                font_weight = curr_tags[0].get_property(cons.TAG_WEIGHT)
                 if curr_tag_str == cons.COLOR_48_BLACK:
                     if former_tag_str != curr_tag_str:
                         former_tag_str = curr_tag_str
@@ -690,35 +690,35 @@ class Export2Html:
             if self.curr_attributes[tag_property] != '':
                 property_value = self.curr_attributes[tag_property]
                 #print property_value
-                if tag_property == "weight":
+                if tag_property == cons.TAG_WEIGHT:
                     # font-weight:bolder
                     #tag_property = "font-weight"
                     #property_value = "bolder"
                     bold_active = True
                     continue
-                elif tag_property == "foreground":
+                elif tag_property == cons.TAG_FOREGROUND:
                     # color:#FFFF00
                     tag_property = "color"
                     property_value = "#" + self.rgb_to_24(property_value[1:])
-                elif tag_property == "background":
+                elif tag_property == cons.TAG_BACKGROUND:
                     # background-color:#FFFF00
                     tag_property = "background-color"
                     property_value = "#" + self.rgb_to_24(property_value[1:])
-                elif tag_property == "style":
+                elif tag_property == cons.TAG_STYLE:
                     # font-style:italic
                     #tag_property = "font-style"
-                    #property_value = "italic"
+                    #property_value = cons.TAG_PROP_ITALIC
                     italic_active = True
                     continue
-                elif tag_property == "underline":
+                elif tag_property == cons.TAG_UNDERLINE:
                     # text-decoration:underline
                     tag_property = "text-decoration"
-                    property_value = "underline"
-                elif tag_property == "strikethrough":
+                    property_value = cons.TAG_UNDERLINE
+                elif tag_property == cons.TAG_STRIKETHROUGH:
                     # text-decoration:line-through
                     tag_property = "text-decoration"
                     property_value = "line-through"
-                elif tag_property == "scale":
+                elif tag_property == cons.TAG_SCALE:
                     if property_value == "sup":
                         superscript_active = True
                         continue
@@ -729,17 +729,17 @@ class Export2Html:
                         # font-size:xx-large/x-large/x-small
                         tag_property = "font-size"
                         if property_value == "small": property_value = "x-small"
-                        elif property_value == "h1": property_value = "xx-large"
-                        elif property_value == "h2": property_value = "x-large"
-                        elif property_value == "h3": property_value = "large"
-                elif tag_property == "family":
+                        elif property_value == cons.TAG_PROP_H1: property_value = "xx-large"
+                        elif property_value == cons.TAG_PROP_H2: property_value = "x-large"
+                        elif property_value == cons.TAG_PROP_H3: property_value = "large"
+                elif tag_property == cons.TAG_FAMILY:
                     monospace_active = True
                     continue
-                elif tag_property == "justification":
+                elif tag_property == cons.TAG_JUSTIFICATION:
                     # text-align:center/left/right
                     #tag_property = "text-align"
                     continue
-                elif tag_property == "link":
+                elif tag_property == cons.TAG_LINK:
                     # <a href="http://www.example.com/">link-text goes here</a>
                     vector = property_value.split()
                     if vector[0] == "webs": href = vector[1]
