@@ -2,7 +2,7 @@
 #
 #       machines.py
 #
-#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -102,10 +102,10 @@ class XMLHandler:
         if not discard_ids:
             self.reset_nodes_names()
             self.dad.bookmarks = []
-        if cherrytree.nodeName != "cherrytree": return False
+        if cherrytree.nodeName != cons.APP_NAME: return False
         else:
             dom_iter = cherrytree.firstChild
-            node_sequence = 0
+            node_sequence = self.dad.nodes_sequences_get_max_siblings(tree_father)
             while dom_iter!= None:
                 if dom_iter.nodeName == "node":
                     node_sequence += 1
@@ -119,7 +119,6 @@ class XMLHandler:
         """Given the dom_iter node, adds it to the tree"""
         if not discard_ids and dom_iter.hasAttribute('unique_id'):
             unique_id = long(dom_iter.attributes['unique_id'].value)
-            self.dad.node_id_add(unique_id)
         else: unique_id = self.dad.node_id_get()
         if dom_iter.hasAttribute('tags'): node_tags = dom_iter.attributes['tags'].value
         else: node_tags = ""
@@ -175,7 +174,7 @@ class XMLHandler:
     def codebox_deserialize(self, curr_buffer, dom_node):
         """From the XML codebox text to the SourceBuffer"""
         char_offset = int(dom_node.attributes["char_offset"].value)
-        justification = dom_node.attributes["justification"].value if dom_node.hasAttribute("justification") else "left"
+        justification = dom_node.attributes[cons.TAG_JUSTIFICATION].value if dom_node.hasAttribute(cons.TAG_JUSTIFICATION) else cons.TAG_PROP_LEFT
         codebox_dict = {
            'frame_width': int(dom_node.attributes['frame_width'].value),
            'frame_height': int(dom_node.attributes['frame_height'].value),
@@ -193,8 +192,8 @@ class XMLHandler:
     def table_deserialize(self, curr_buffer, dom_node):
         """From the XML table text to the SourceBuffer"""
         char_offset = int(dom_node.attributes["char_offset"].value)
-        if dom_node.hasAttribute("justification"): justification = dom_node.attributes["justification"].value
-        else: justification = "left"
+        if dom_node.hasAttribute(cons.TAG_JUSTIFICATION): justification = dom_node.attributes[cons.TAG_JUSTIFICATION].value
+        else: justification = cons.TAG_PROP_LEFT
         table_dict = {
             'matrix': [],
             'col_min': int(dom_node.attributes['col_min'].value),
@@ -220,8 +219,8 @@ class XMLHandler:
     def image_deserialize(self, curr_buffer, dom_node, version):
         """From the XML embedded image text to the SourceBuffer"""
         char_offset = int(dom_node.attributes["char_offset"].value)
-        if dom_node.hasAttribute("justification"): justification = dom_node.attributes["justification"].value
-        else: justification = "left"
+        if dom_node.hasAttribute(cons.TAG_JUSTIFICATION): justification = dom_node.attributes[cons.TAG_JUSTIFICATION].value
+        else: justification = cons.TAG_PROP_LEFT
         if dom_node.hasAttribute("anchor"):
             pixbuf = gtk.gdk.pixbuf_new_from_file(cons.ANCHOR_CHAR)
             pixbuf = pixbuf.scale_simple(self.dad.anchor_size, self.dad.anchor_size, gtk.gdk.INTERP_BILINEAR)
@@ -258,7 +257,7 @@ class XMLHandler:
         """Parse the Given Node and Subnodes and Generate an XML Cherry Tree Document"""
         if "dom" in dir(self): del self.dom
         self.dom = xml.dom.minidom.Document()
-        cherrytree = self.dom.createElement("cherrytree")
+        cherrytree = self.dom.createElement(cons.APP_NAME)
         self.dom.appendChild(cherrytree)
         # given node and subnodes parsing
         self.append_dom_node(tree_iter, cherrytree, to_disk=True, skip_children=True, sel_range=sel_range)
@@ -268,7 +267,7 @@ class XMLHandler:
         """Parse the Given Node and Subnodes and Generate an XML Cherry Tree Document"""
         if "dom" in dir(self): del self.dom
         self.dom = xml.dom.minidom.Document()
-        cherrytree = self.dom.createElement("cherrytree")
+        cherrytree = self.dom.createElement(cons.APP_NAME)
         self.dom.appendChild(cherrytree)
         # given node and subnodes parsing
         self.append_dom_node(tree_iter, cherrytree, to_disk=True)
@@ -278,7 +277,7 @@ class XMLHandler:
         """Parse the Tree and Generate an XML Cherry Tree Document"""
         if "dom" in dir(self): del self.dom
         self.dom = xml.dom.minidom.Document()
-        cherrytree = self.dom.createElement("cherrytree")
+        cherrytree = self.dom.createElement(cons.APP_NAME)
         self.dom.appendChild(cherrytree)
         # full tree parsing
         tree_iter = self.dad.treestore.get_iter_first()
@@ -352,7 +351,7 @@ class XMLHandler:
         """From element [char_offset, codebox, justification] to dom node"""
         dom_iter = self.dom.createElement("codebox")
         dom_iter.setAttribute("char_offset", str(element[0]))
-        if element[2] != "left": dom_iter.setAttribute("justification", element[2])
+        if element[2] != cons.TAG_PROP_LEFT: dom_iter.setAttribute(cons.TAG_JUSTIFICATION, element[2])
         dom_iter.setAttribute("frame_width", str(element[1]['frame_width']))
         dom_iter.setAttribute("frame_height", str(element[1]['frame_height']))
         dom_iter.setAttribute("width_in_pixels", str(element[1]['width_in_pixels']))
@@ -367,7 +366,7 @@ class XMLHandler:
         """From element [char_offset, table, justification] to dom node"""
         dom_iter = self.dom.createElement("table")
         dom_iter.setAttribute("char_offset", str(element[0]))
-        if element[2] != "left": dom_iter.setAttribute("justification", element[2])
+        if element[2] != cons.TAG_PROP_LEFT: dom_iter.setAttribute(cons.TAG_JUSTIFICATION, element[2])
         dom_iter.setAttribute("col_min", str(element[1]['col_min']))
         dom_iter.setAttribute("col_max", str(element[1]['col_max']))
         dom_node.appendChild(dom_iter)
@@ -384,7 +383,7 @@ class XMLHandler:
         """From element [char_offset, pixbuf, justification] to dom node"""
         dom_iter = dom.createElement("encoded_png")
         dom_iter.setAttribute("char_offset", str(element[0]))
-        if element[2] != "left": dom_iter.setAttribute("justification", element[2])
+        if element[2] != cons.TAG_PROP_LEFT: dom_iter.setAttribute(cons.TAG_JUSTIFICATION, element[2])
         if "anchor" in dir(element[1]):
             dom_iter.setAttribute("anchor", element[1].anchor)
             is_anchor_image = True
@@ -416,35 +415,35 @@ class XMLHandler:
         for tag in toggled_off:
             tag_name = tag.get_property("name")
             if tag_name:
-                if tag_name[0:7] == "weight_": curr_attributes["weight"] = ""
-                elif tag_name[0:11] == "foreground_": curr_attributes["foreground"] = ""
-                elif tag_name[0:11] == "background_": curr_attributes["background"] = ""
-                elif tag_name[0:6] == "style_": curr_attributes["style"] = ""
-                elif tag_name[0:10] == "underline_": curr_attributes["underline"] = ""
-                elif tag_name[0:14] == "strikethrough_": curr_attributes["strikethrough"] = ""
-                elif tag_name[0:6] == "scale_": curr_attributes["scale"] = ""
-                elif tag_name[0:14] == "justification_": curr_attributes["justification"] = ""
-                elif tag_name[0:5] == "link_": curr_attributes["link"] = ""
-                elif tag_name[0:7] == "family_": curr_attributes["family"] = ""
+                if tag_name[0:7] == "weight_": curr_attributes[cons.TAG_WEIGHT] = ""
+                elif tag_name[0:11] == "foreground_": curr_attributes[cons.TAG_FOREGROUND] = ""
+                elif tag_name[0:11] == "background_": curr_attributes[cons.TAG_BACKGROUND] = ""
+                elif tag_name[0:6] == "style_": curr_attributes[cons.TAG_STYLE] = ""
+                elif tag_name[0:10] == "underline_": curr_attributes[cons.TAG_UNDERLINE] = ""
+                elif tag_name[0:14] == "strikethrough_": curr_attributes[cons.TAG_STRIKETHROUGH] = ""
+                elif tag_name[0:6] == "scale_": curr_attributes[cons.TAG_SCALE] = ""
+                elif tag_name[0:14] == "justification_": curr_attributes[cons.TAG_JUSTIFICATION] = ""
+                elif tag_name[0:5] == "link_": curr_attributes[cons.TAG_LINK] = ""
+                elif tag_name[0:7] == "family_": curr_attributes[cons.TAG_FAMILY] = ""
                 else: support.dialog_error("Failure processing the toggling OFF tag %s" % tag_name, self.dad.window)
         toggled_on = curr_iter.get_toggled_tags(toggled_on=True)
         for tag in toggled_on:
             tag_name = tag.get_property("name")
             if tag_name:
-                if tag_name[0:7] == "weight_": curr_attributes["weight"] = tag_name[7:]
+                if tag_name[0:7] == "weight_": curr_attributes[cons.TAG_WEIGHT] = tag_name[7:]
                 elif tag_name[0:11] == "foreground_":
                     new_foreground = tag_name[11:]
-                    if new_foreground != cons.COLOR_48_BLACK: curr_attributes["foreground"] = new_foreground
+                    if new_foreground != cons.COLOR_48_BLACK: curr_attributes[cons.TAG_FOREGROUND] = new_foreground
                 elif tag_name[0:11] == "background_":
                     new_background = tag_name[11:]
-                    if new_background != cons.COLOR_48_WHITE: curr_attributes["background"] = new_background
-                elif tag_name[0:6] == "scale_": curr_attributes["scale"] = tag_name[6:]
-                elif tag_name[0:14] == "justification_": curr_attributes["justification"] = tag_name[14:]
-                elif tag_name[0:6] == "style_": curr_attributes["style"] = tag_name[6:]
-                elif tag_name[0:10] == "underline_": curr_attributes["underline"] = tag_name[10:]
-                elif tag_name[0:14] == "strikethrough_": curr_attributes["strikethrough"] = tag_name[14:]
-                elif tag_name[0:5] == "link_": curr_attributes["link"] = tag_name[5:]
-                elif tag_name[0:7] == "family_": curr_attributes["family"] = tag_name[7:]
+                    if new_background != cons.COLOR_48_WHITE: curr_attributes[cons.TAG_BACKGROUND] = new_background
+                elif tag_name[0:6] == "scale_": curr_attributes[cons.TAG_SCALE] = tag_name[6:]
+                elif tag_name[0:14] == "justification_": curr_attributes[cons.TAG_JUSTIFICATION] = tag_name[14:]
+                elif tag_name[0:6] == "style_": curr_attributes[cons.TAG_STYLE] = tag_name[6:]
+                elif tag_name[0:10] == "underline_": curr_attributes[cons.TAG_UNDERLINE] = tag_name[10:]
+                elif tag_name[0:14] == "strikethrough_": curr_attributes[cons.TAG_STRIKETHROUGH] = tag_name[14:]
+                elif tag_name[0:5] == "link_": curr_attributes[cons.TAG_LINK] = tag_name[5:]
+                elif tag_name[0:7] == "family_": curr_attributes[cons.TAG_FAMILY] = tag_name[7:]
                 else: support.dialog_error("Failure processing the toggling ON tag %s" % tag_name, self.dad.window)
 
     def toc_insert_all(self, text_buffer, top_tree_iter):
@@ -461,7 +460,7 @@ class XMLHandler:
         #print toc_list_per_node
         curr_node_id = -1
         if toc_list_per_node:
-            tag_property = "link"
+            tag_property = cons.TAG_LINK
             curr_offset = 0
             text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), cons.CHAR_NEWLINE)
             curr_offset += 1
@@ -479,10 +478,10 @@ class XMLHandler:
                     text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), cons.CHAR_NEWLINE)
                     curr_offset += 1
                 tag_names = [self.dad.apply_tag_exist_or_create(tag_property, property_value + cons.CHAR_SPACE + element[0])]
-                if element[0][:2] == "h1":
+                if element[0][:2] == cons.TAG_PROP_H1:
                     text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), 3*cons.CHAR_SPACE + cons.CHAR_LISTBUL + cons.CHAR_SPACE)
                     curr_offset += 5
-                elif element[0][:2] == "h2":
+                elif element[0][:2] == cons.TAG_PROP_H2:
                     text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), 6*cons.CHAR_SPACE + cons.CHAR_LISTBUL + cons.CHAR_SPACE)
                     curr_offset += 8
                 else:
@@ -512,7 +511,7 @@ class XMLHandler:
     def toc_insert_one(self, text_buffer, node_id, just_get_toc_list=False):
         """Given the text_buffer, inserts the Table Of Contents"""
         self.curr_attributes = {}
-        self.toc_counters = {"h1":0, "h2":0, "h3":0}
+        self.toc_counters = {cons.TAG_PROP_H1:0, cons.TAG_PROP_H2:0, cons.TAG_PROP_H3:0}
         self.toc_list = [] # 0: anchor name; 1: text in h1, h2 or h3; 2:node id
         for tag_property in cons.TAG_PROPERTIES: self.curr_attributes[tag_property] = ""
         start_iter = text_buffer.get_start_iter()
@@ -535,7 +534,7 @@ class XMLHandler:
                 if curr_iter.get_offset() == offset_old: break
         else: self.toc_insert_parser(text_buffer, start_iter, curr_iter, node_id)
         if self.toc_list and not just_get_toc_list:
-            tag_property = "link"
+            tag_property = cons.TAG_LINK
             property_value = "node" + cons.CHAR_SPACE + str(node_id)
             curr_offset = 0
             text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), cons.CHAR_NEWLINE)
@@ -543,10 +542,10 @@ class XMLHandler:
             for element in self.toc_list:
                 tag_names = []
                 tag_names.append(self.dad.apply_tag_exist_or_create(tag_property, property_value + cons.CHAR_SPACE + element[0]))
-                if element[0][:2] == "h1":
+                if element[0][:2] == cons.TAG_PROP_H1:
                     text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), cons.CHAR_LISTBUL + cons.CHAR_SPACE)
                     curr_offset += 2
-                elif element[0][:2] == "h2":
+                elif element[0][:2] == cons.TAG_PROP_H2:
                     text_buffer.insert(text_buffer.get_iter_at_offset(curr_offset), 3*cons.CHAR_SPACE + cons.CHAR_LISTBUL + cons.CHAR_SPACE)
                     curr_offset += 5
                 else:
@@ -561,18 +560,18 @@ class XMLHandler:
 
     def toc_insert_parser(self, text_buffer, start_iter, end_iter, node_id):
         """Parses a Tagged String for the TOC insert"""
-        if self.curr_attributes["scale"] not in ["h1", "h2", "h3"]: return None
+        if self.curr_attributes[cons.TAG_SCALE] not in [cons.TAG_PROP_H1, cons.TAG_PROP_H2, cons.TAG_PROP_H3]: return None
         start_offset = start_iter.get_offset()
         end_offset = end_iter.get_offset()
-        if self.curr_attributes["scale"] == "h1":
-            self.toc_counters["h1"] += 1
-            self.toc_list.append(["h1-%d" % self.toc_counters["h1"], text_buffer.get_text(start_iter, end_iter), node_id])
-        elif self.curr_attributes["scale"] == "h2":
-            self.toc_counters["h2"] += 1
-            self.toc_list.append(["h2-%d" % self.toc_counters["h2"], text_buffer.get_text(start_iter, end_iter), node_id])
+        if self.curr_attributes[cons.TAG_SCALE] == cons.TAG_PROP_H1:
+            self.toc_counters[cons.TAG_PROP_H1] += 1
+            self.toc_list.append(["h1-%d" % self.toc_counters[cons.TAG_PROP_H1], text_buffer.get_text(start_iter, end_iter), node_id])
+        elif self.curr_attributes[cons.TAG_SCALE] == cons.TAG_PROP_H2:
+            self.toc_counters[cons.TAG_PROP_H2] += 1
+            self.toc_list.append(["h2-%d" % self.toc_counters[cons.TAG_PROP_H2], text_buffer.get_text(start_iter, end_iter), node_id])
         else:
-            self.toc_counters["h3"] += 1
-            self.toc_list.append(["h3-%d" % self.toc_counters["h3"], text_buffer.get_text(start_iter, end_iter), node_id])
+            self.toc_counters[cons.TAG_PROP_H3] += 1
+            self.toc_list.append(["h3-%d" % self.toc_counters[cons.TAG_PROP_H3], text_buffer.get_text(start_iter, end_iter), node_id])
         anchor_start = start_iter.copy()
         if anchor_start.backward_char():
             anchor = anchor_start.get_child_anchor()
@@ -662,11 +661,11 @@ class StateMachine:
 
     def get_iter_alignment(self, iter_text):
         """Get the Alignment Value of the given Iter"""
-        align_center = self.dad.apply_tag_exist_or_create("justification", "center")
-        align_right = self.dad.apply_tag_exist_or_create("justification", "right")
-        if iter_text.has_tag(self.dad.tag_table.lookup(align_center)): return "center"
-        elif iter_text.has_tag(self.dad.tag_table.lookup(align_right)): return "right"
-        else: return "left"
+        align_center = self.dad.apply_tag_exist_or_create(cons.TAG_JUSTIFICATION, cons.TAG_PROP_CENTER)
+        align_right = self.dad.apply_tag_exist_or_create(cons.TAG_JUSTIFICATION, cons.TAG_PROP_RIGHT)
+        if iter_text.has_tag(self.dad.tag_table.lookup(align_center)): return cons.TAG_PROP_CENTER
+        elif iter_text.has_tag(self.dad.tag_table.lookup(align_right)): return cons.TAG_PROP_RIGHT
+        else: return cons.TAG_PROP_LEFT
 
     def load_embedded_image_element(self, text_buffer, element):
         """Load an Image from the Embedded Vector into the Buffer"""
@@ -700,7 +699,7 @@ class StateMachine:
         if justification == None: return
         iter_end = iter_start.copy()
         iter_end.forward_char()
-        self.dad.apply_tag("justification",
+        self.dad.apply_tag(cons.TAG_JUSTIFICATION,
                            justification,
                            iter_sel_start=iter_start,
                            iter_sel_end=iter_end,
@@ -799,7 +798,7 @@ class StateMachine:
         if curr_index != last_index: del self.nodes_vectors[node_id][curr_index+1:last_index+1]
         xml_content = self.dad.xml_handler.treestore_node_to_dom(self.dad.curr_tree_iter)
         pixbuf_table_codebox_vector = self.get_embedded_pixbufs_tables_codeboxes(self.dad.curr_buffer)
-        cursor_pos = self.dad.curr_buffer.get_property('cursor-position')
+        cursor_pos = self.dad.curr_buffer.get_property(cons.STR_CURSOR_POSITION)
         self.nodes_vectors[node_id].append([xml_content, pixbuf_table_codebox_vector, cursor_pos])
         num_saved_states = len(self.nodes_vectors[node_id])
         if num_saved_states == 2: self.nodes_vectors[node_id][0][2] = cursor_pos
